@@ -12,7 +12,7 @@ from aiohttp_sqlalchemy.typedefs import THandler, THandlerWrapper
 def sa_decorator(key: str = SA_DEFAULT_KEY) -> THandlerWrapper:
     """SQLAlchemy asynchronous handler decorator.
 
-    :param key: key of SQLAlchemy binding. Has default.
+    :param key: key of SQLAlchemy binding.
     """
 
     def wrapper(handler: THandler) -> THandler:
