@@ -15,9 +15,9 @@ async def init_db(
 ) -> None:
     """Create all tables, indexes and etc.
 
-    :param app: instance of ``aiohttp.web_app.Application``.
-    :param metadata: instance of ``sqlalchemy.scql.schema.MetaData``.
-    :param key: key of SQLAlchemy binding. Has default.
+    :param app: your AIOHTTP application.
+    :param metadata: ...
+    :param key: key of SQLAlchemy binding.
     """
     session_factory = sa_session_factory(app, key)
     async with session_factory() as session:
@@ -29,10 +29,10 @@ def sa_session(
     request: Request,
     key: str = SA_DEFAULT_KEY,
 ) -> AsyncSession:
-    """Return ``AsyncSession`` instance.
+    """Return `AsyncSession` instance.
 
-    :param request: instance of ``aiohttp.web_request.Request``.
-    :param key: key of SQLAlchemy binding. Has default.
+    :param request: AIOHTTP request object.
+    :param key: key of SQLAlchemy binding.
     """
     if not isinstance(request, Request):
         raise TypeError(f"{request} is not {Request}.")
@@ -48,11 +48,10 @@ def sa_session_factory(
     source: Union[Request, Application],
     key: str = SA_DEFAULT_KEY,
 ) -> TSessionFactory:
-    """Return callable object which returns an ``AsyncSession`` instance.
+    """Return callable object which returns an `AsyncSession` instance.
 
-    :param sorce: instance of ``aiohttp.web_request.Request`` or
-                  ``aiohttp.web_app.Application``.
-    :param key: key of SQLAlchemy binding. Has default.
+    :param source: AIOHTTP request object or your AIOHTTP application.
+    :param key: key of SQLAlchemy binding.
     """
     return cast(TSessionFactory, getattr(source, "app", source).get(key))
 
